@@ -731,11 +731,13 @@ class MockRpmBuilder(RpmBuilder):
         self.init_chroot()
         self.mock('--install', 'yum-utils', '--quiet', output=False) # for repoquery
         cmd = ['repoquery']
-        cmd.append('--show-dupes')
+        cmd.append('--quiet')
+        cmd.append('--show-duplicates')
         cmd.append('--queryformat="%{VERSION}-%{RELEASE}"')
         cmd.append('kernel-devel')
+        cmd.append('2>/dev/null')
         logger.debug('Searching for kernel-devel in enabled repos.')
-        output = self.mock('--quiet', '--chroot', ' '.join(cmd), quiet=True)
+        output = self.mock('--enable-network', '--quiet', '--chroot', ' '.join(cmd), quiet=True)
         versions = []
         for line in output:
             if line.startswith('rpmdb:'):
